# -*- coding: utf-8 -*-
# @Author: root
# @Date:   2016-05-24 16:24:54
# @Last Modified by:   drinks
# @Last Modified time: 2016-05-24 23:00:05

from colorfulprinter import PrettyPrinter
pp = PrettyPrinter(indent=4)
a = [1, 2, 3, [1, 2, 3, [1, 2, 3]]]
pp.pprint(a)



# -*- coding: utf-8 -*-
# @Author: linlin
# @Date:   2016-05-24 16:20:39
# @Last Modified by:   drinks
# @Last Modified time: 2016-05-25 10:58:51
# try:
from .npprint import PrettyPrinter, pformat, isreadable, isrecursive, saferepr, pprint
from .termcolor import color_write, cprint
__all__ = ("pprint", "pformat", "isreadable", "isrecursive", "saferepr",
           "PrettyPrinter", 'color_write', 'cprint')

